@@ -1,4 +1,4 @@
-/* $Id: mem.h,v 1.14 1999/02/23 11:42:56 martin Exp $ */
+/* $Id: mem.h,v 1.22 2003/10/20 15:19:39 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_MEM_TOTAL	0
 #define GLIBTOP_MEM_USED	1
@@ -84,6 +84,6 @@ extern const char *glibtop_descriptions_mem [];
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
