@@ -1,4 +1,4 @@
-/* $Id: ppp.h,v 1.14 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: ppp.h,v 1.15 2003/10/20 15:19:39 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_PPP_STATE	0
 #define GLIBTOP_PPP_BYTES_IN	1	
@@ -80,6 +80,6 @@ extern const char *glibtop_descriptions_ppp [];
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
