@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.25 2005/12/12 09:38:11 jamesh Exp $ */
+/* $Id: proclist.c,v 1.21 2003/10/20 15:19:50 hadess Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -21,7 +21,6 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/proclist.h>
@@ -60,7 +59,7 @@ glibtop_init_proclist_p (glibtop *server)
 
 unsigned *
 glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
-			gint64 real_which, gint64 arg)
+			int64_t real_which, int64_t arg)
 {
 	struct kinfo_proc *pinfo;
 	unsigned *pids = NULL;
@@ -68,7 +67,7 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 	int i,j;
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROCLIST), 0);
-
+	
 	memset (buf, 0, sizeof (glibtop_proclist));
 
 	which = (int)(real_which & GLIBTOP_KERN_PROC_MASK);
@@ -86,25 +85,13 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 	pids = g_realloc (pids, count * sizeof (unsigned));
 	/* Copy the pids over to this chain */
 	for (i=j=0; i < count; i++) {
-#if defined(__FreeBSD__) && (__FreeBSD_version >= 500013)
-#define PROC_STAT	ki_stat
-#define PROC_RUID	ki_ruid
-#define PROC_PID	ki_pid
-
-#else
-#define PROC_STAT	kp_proc.p_stat
-#define PROC_RUID	kp_eproc.e_pcred.p_ruid
-#define PROC_PID	kp_proc.p_pid
-
-#endif
-
 		if ((real_which & GLIBTOP_EXCLUDE_IDLE) &&
-		    (pinfo[i].PROC_STAT != SRUN))
+		    (pinfo[i].kp_proc.p_stat != SRUN))
 			continue;
 		else if ((real_which & GLIBTOP_EXCLUDE_SYSTEM) &&
-			 (pinfo[i].PROC_RUID == 0))
+			 (pinfo[i].kp_eproc.e_pcred.p_ruid == 0))
 			continue;
-		pids [j++] = (unsigned) pinfo[i].PROC_PID;
+		pids [j++] = (unsigned) pinfo[i].kp_proc.p_pid;
 	} /* end for */
 	/* Set the fields in buf */
 	buf->number = j;
