@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.24.2.1 2003/10/20 19:53:57 hadess Exp $ */
+/* $Id: swap.c,v 1.26 2003/10/20 15:19:50 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -25,8 +25,6 @@
 #include <glibtop/error.h>
 #include <glibtop/swap.h>
 
-#include <glibtop/xmalloc.h>
-
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_swap =
@@ -269,14 +267,14 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	/* List of swap devices and sizes. */
 
 	sw_size = nswdev * sizeof (*sw);
-	sw = glibtop_malloc_r (server, sw_size);
+	sw = g_malloc (server, sw_size);
 
 	if (kvm_read (server->machine.kd, ptr, sw, sw_size) != (ssize_t)sw_size) {
 		glibtop_warn_io_r (server, "kvm_read (*swdevt)");
 		return;
 	}
 
-	perdev = glibtop_malloc (nswdev * sizeof (*perdev));
+	perdev = g_malloc (nswdev * sizeof (*perdev));
 
 	/* Count up swap space. */
 
@@ -353,8 +351,8 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	 */
 	inuse = avail - nfree;
 
-	glibtop_free_r (server, sw);
-	glibtop_free_r (server, perdev);
+	g_free (sw);
+	g_free (perdev);
 
 	buf->flags = _glibtop_sysdeps_swap;
 
@@ -369,8 +367,8 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 
 	buf->flags = _glibtop_sysdeps_swap;
 
-	buf->used = kvmsw[nswdev].ksw_used * getpagesize(); 
-	buf->total = kvmsw[nswdev].ksw_total * getpagesize();
+	buf->used = kvmsw[nswdev].ksw_used;
+	buf->total = kvmsw[nswdev].ksw_total;
 
 	buf->free = buf->total - buf->used;
 
@@ -401,11 +399,11 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 		return;
 	}
 
-	swaplist = glibtop_calloc_r (server, nswap, sizeof (struct swapent));
+	swaplist = g_malloc (server, nswap * sizeof (struct swapent));
 
 	if (swapctl (SWAP_STATS, swaplist, nswap) != nswap) {
 		glibtop_warn_io_r (server, "swapctl (SWAP_STATS)");
-		glibtop_free_r (server, swaplist);
+		g_free (swaplist);
 		return;
 	}
 
@@ -414,7 +412,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 		inuse += swaplist[i].se_inuse;
 	}
 
-	glibtop_free_r (server, swaplist);
+	g_free (swaplist);
 
 	buf->flags = _glibtop_sysdeps_swap;
 
