@@ -1,3 +1,5 @@
+/* $Id: ppp.c,v 1.16 2003/10/20 15:19:56 hadess Exp $ */
+
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -19,11 +21,11 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/ppp.h>
 
+#include <linux/isdn.h>
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -32,13 +34,6 @@
 
 #include <glib.h>
 
-#ifdef HAVE_ISDN_H
-#include <linux/isdn.h>
-#else
-#define ISDN_MAX_CHANNELS 64
-#define IIOCGETCPS  _IO('I',21)
-#endif /* HAVE_ISDN_H */
-
 static const unsigned long _glibtop_sysdeps_ppp =
 (1L << GLIBTOP_PPP_STATE) + (1L << GLIBTOP_PPP_BYTES_IN) +
 (1L << GLIBTOP_PPP_BYTES_OUT);
@@ -51,37 +46,42 @@ glibtop_init_ppp_s (glibtop *server)
 	server->sysdeps.ppp = _glibtop_sysdeps_ppp;
 }
 
-static gboolean
+static int
 get_ISDN_stats (glibtop *server, int *in, int *out)
 {
-	unsigned long isdn_stats[2 * ISDN_MAX_CHANNELS], *ptr;
-	int fd;
-
+	unsigned long *isdn_stats, *ptr;
+	int fd, i;
+	
 	*in = *out = 0;
 
+	isdn_stats = g_malloc (ISDN_MAX_CHANNELS * 2 * sizeof (unsigned long));
+
 	fd = open ("/dev/isdninfo", O_RDONLY);
 	if (fd < 0) {
+		g_free (isdn_stats);
 		return FALSE;
 	}
 
 	if ((ioctl (fd, IIOCGETCPS, isdn_stats) < 0) && (errno != 0)) {
-		close(fd);
+		g_free (isdn_stats);
+		close (fd);
+		
 		return FALSE;
 	}
 
-	for (ptr = isdn_stats;
-	     ptr != (isdn_stats + G_N_ELEMENTS(isdn_stats));
-	     /* NOOP */) {
+	for (i = 0, ptr = isdn_stats; i < ISDN_MAX_CHANNELS; i++) {
 		*in  += *ptr++; *out += *ptr++;
 	}
 
+	g_free (isdn_stats);
 	close (fd);
+
 	return TRUE;
 }
 
-static gboolean is_ISDN_on (glibtop *server, int *online)
+static int is_ISDN_on (glibtop *server, int *online)
 {
-	FILE *f = NULL;
+	FILE *f = 0;
 	char buffer [BUFSIZ], *p;
 	int i;
 
