@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.15 2003/10/19 16:55:43 carlos Exp $ */
+/* $Id: proclist.c,v 1.17 2003/10/20 15:20:05 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,7 +23,6 @@
 
 #include <glibtop.h>
 #include <glibtop/error.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/proclist.h>
 
 #include <glibtop_suid.h>
@@ -108,15 +107,15 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 
 			if (count >= BLOCK_COUNT) {
 
-				/* The following call to glibtop_realloc ()
-				 * will be equivalent to glibtop_malloc ()
+				/* The following call to g_realloc ()
+				 * will be equivalent to g_malloc ()
 				 * if `pids_chain' is NULL. We just calculate
 				 * the new size and copy `pids' to the
 				 * beginning of the newly allocated block. */
 
 				new_size = pids_size + BLOCK_SIZE;
 
-				pids_chain = glibtop_realloc_r
+				pids_chain = g_realloc
 					(server, pids_chain, new_size);
 
 				memcpy (pids_chain + pids_offset,
@@ -143,14 +142,14 @@ glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
 
 	if (!count) return NULL;
 
-	/* The following call to glibtop_realloc () will be equivalent to
-	 * glibtop_malloc () if `pids_chain' is NULL. We just calculate the
+	/* The following call to g_realloc () will be equivalent to
+	 * g_malloc () if `pids_chain' is NULL. We just calculate the
 	 * new size and copy `pids' to the beginning of the newly allocated
 	 * block. */
 	
 	new_size = pids_size + count * sizeof (unsigned);
 	
-	pids_chain = glibtop_realloc_r (server, pids_chain, new_size);
+	pids_chain = g_realloc (server, pids_chain, new_size);
 	
 	memcpy (pids_chain + pids_offset, pids, count * sizeof (unsigned));
 	
